# modified from https://nl.wikipedia.org/wiki/Lijst_van_beroepen

job_formats_nl_nl <- c(
  "Aankondiger",
  "Acceptant",
  "Accountant",
  "Accountmanager",
  "Acrobaat (Acrobate)",
  "Acteur (Actrice)",
  "Activiteitenbegeleider",
  "Actuaris",
  "Acupuncturist",
  "Adjudant",
  "Administrateur",
  "Advertentiezetter",
  "Adviseur (Adviseuse)",
  "Advocaat (Advocate)",
  "Agent(e)",
  "Agoog (Agoge)",
  "Agrari\u00ebr",
  "Akoepedist",
  "Akoesticus",
  "Alchemist",
  "Allergoloog",
  "Altist",
  "Amanuensis",
  "Ambtenaar",
  "Ambulancebegeleider",
  "Ambulancechauffeur",
  "Ambulanceverpleegkundige",
  "Analist (laboratorium)",
  "Anatoom",
  "Andragoog",
  "Androloog",
  "Anesthesist",
  "Anesthesiemedewerker",
  "Animeermeisje",
  "Antiquaar",
  "Antiquair",
  "Apotheker",
  "Apothekersassistent",
  "Applicatieontwikkelaar",
  "Arbeidsanalist",
  "Arbeidsbemiddelaar",
  "Arbeidsdeskundige",
  "Arbeidsfysioloog",
  "Arbeidsgeneesheer",
  "Arbeidshygi\u00ebnist",
  "Archeoloog",
  "Architect",
  "Archivaris",
  "Archivist",
  "Arrangeur",
  "Artdirector",
  "Artiest",
  "Arts",
  "Assuradeur",
  "Astrofysicus",
  "Astroloog",
  "Astronaut",
  "Astronoom",
  "Audioloog",
  "Audiometrist",
  "Audiotherapeut",
  "Auditor",
  "Autohandelaar",
  "Automonteur",
  "Autoplaatwerker",
  "Autospuiter",
  "Bacterioloog",
  "Badmeester",
  "Baggermachinist",
  "Baggermolenarbeider",
  "Baker",
  "Bakker",
  "Baliemedewerker",
  "Balletdanser",
  "Ballroomdanser",
  "Bandagist",
  "Bandenmonteur",
  "Bankbediende",
  "Bankdirecteur",
  "Banketbakker",
  "Bankmakelaar",
  "Bankwerker",
  "Barbediende",
  "Barhouder",
  "Barman",
  "Basketballer",
  "Bassist",
  "Beademingsassistent",
  "Bedienaar",
  "Bediener",
  "Bedrijfsbrandweer",
  "Bedrijfseconoom",
  "Bedrijfshoofd",
  "Bedrijfsjurist",
  "Bedrijfskassier",
  "Bedrijfskundige",
  "Bedrijfsleermeester",
  "Bedrijfsleider",
  "Bedrijfsorganisatiedeskundige",
  "Bedrijfspolitieagent",
  "Bedrijfsrecherche",
  "Bedrijfsverpleegkundige",
  "Beeldapparatuurbediener",
  "Beeldhouwer",
  "Beenhouwer",
  "Begeleider",
  "Begrafenispersoneel",
  "Begrotingscalculator",
  "Behanger",
  "Beheerder",
  "Beiaardier",
  "Bejaardenverzorgende",
  "Belastingambtenaar",
  "Belastingconsulent",
  "Beleidsambtenaar",
  "Beleidsmedewerker",
  "Belichter",
  "Bergingsduiker",
  "Beroepskeuzeadviseur",
  "Beroepsmilitair",
  "Beroepssporter",
  "Bestekschrijver",
  "Besteksorteerder",
  "Bestekzoeker",
  "Bestuurder",
  "Bestuurskundige",
  "Betonmolenbaas",
  "Betontimmerman",
  "Betonstaalvlechter",
  "Betonwerker",
  "Beul",
  "Beveiligingsapparatuur",
  "Beveiligingsbeambte",
  "Bewaarder",
  "Bewaker",
  "Bewegingstherapeut",
  "Bezorger",
  "Bibliothecaris",
  "Bibliotheekassistent",
  "Bierbrouwer",
  "Bijenkorfvlechter",
  "Bijenkweker",
  "Bijkantoorhouder",
  "Binderijpersoneel",
  "Binnenhuisarchitect",
  "Biochemicus",
  "Biograaf",
  "Bioloog",
  "Bioscoopoperateur",
  "Bitumineerder",
  "Bloemist",
  "Bloemkweker",
  "Bloemschikker",
  "Bloemsierkunstenaar",
  "Bode",
  "Boekbinder",
  "Boekhouder",
  "Boekillustrator",
  "Boer",
  "Bontkleermaker",
  "Bontsnijder",
  "Bookmaker",
  "Boomchirurg",
  "Boomkweker",
  "Boomverzorger",
  "Boordwerktuigkundige",
  "Boormachinist",
  "Boorpersoneel",
  "Bootsman",
  "Bosbaas",
  "Bosbouwkundige",
  "Boswachter",
  "Botenbouwer",
  "Bouwcalculator",
  "Bouwhistoricus",
  "Bouwkundig tekenaar",
  "Bouwliftbediener",
  "Bouwpromotor",
  "Bouwopzichter",
  "Bouwvakker (incl. bouwvakarbeider)",
  "Bouwvaktimmerman",
  "Brandmeester",
  "Brandveiligheidsdeskundige",
  "Brandwacht",
  "Brandweerman (brandweervrouw)",
  "Brandweercommandant",
  "Brandweeronderofficier",
  "Breimachinesteller",
  "Bromfietshersteller",
  "Bronboorder",
  "Buffetbediende",
  "Buikspreker",
  "Buitenbandenvulkaniseur",
  "Buitendienstmedewerker",
  "Burgemeester",
  "Buschauffeur",
  "Budgetcoach",
  "Butler",
  "Cabaretier",
  "Caf\u00e9houder",
  "Cafetariamedewerker",
  "Caissi\u00e8re",
  "Calculator",
  "Callgirl",
  "Cameraman (- vrouw)",
  "Cardioloog",
  "Cargadoor",
  "Carrosseriebouwer",
  "Cartograaf",
  "Cellist",
  "Chauffeur",
  "Chef",
  "Chemicus",
  "Chiropodist",
  "Chirurg",
  "Chocolademaker",
  "Chocolatier",
  "Choreograaf",
  "Cilindermaker",
  "Cineast",
  "Cipier",
  "Circusartiest",
  "Circusdirecteur",
  "Civiel ingenieur",
  "Classicus",
  "Clown",
  "Coach",
  "Codeur",
  "Collationist",
  "Colporteur",
  "Columnist",
  "Combinatiefunctionaris",
  "Commentator",
  "Commissaris",
  "Commissionair",
  "Completeerder",
  "Compliance officer",
  "Componist",
  "Computeroperator",
  "Computerprogrammeur",
  "Conci\u00ebrge",
  "Conducteur",
  "Conservator",
  "Constructeur",
  "Constructiebankwerker",
  "Constructiesamenbouwer",
  "Constructieschilder",
  "Consulent",
  "Contactlensspecialist",
  "Controleur",
  "Controller",
  "Co\u00f6rdinator",
  "Copywriter",
  "Counselor",
  "Corrector",
  "Correpetitor",
  "Correspondent",
  "Creatief therapeut",
  "Cr\u00e8cheleidster",
  "Criminoloog",
  "Criticus",
  "Croupeur",
  "Croupier",
  "Cultuurtechnicus",
  "Curator",
  "Cursusco\u00f6rdinator",
  "Cursusleider",
  "Dakdekker",
  "Dakpannenvormer",
  "Danser",
  "Dansleraar",
  "Database administrator",
  "Debitant",
  "Decaan",
  "Declarant",
  "Decoratieschilder",
  "Decorschilder",
  "Degelpersdrukker",
  "Dekkledenmaker",
  "Dekpersoneel",
  "Delfstoffenbewerker",
  "Demonstrateur",
  "Dermatoloog",
  "Deskundige",
  "Detailhandelaar",
  "Detective",
  "Deurenzetter",
  "Deurwaarder",
  "Dichter",
  "Dieetkok",
  "Dienstbode",
  "Dienstleider",
  "Diepdrukgraveur",
  "Dierenarts",
  "Dierenartsassistent",
  "Dierenasielhouder",
  "Dierentrainer",
  "Dierenverzorger",
  "Di\u00ebtist",
  "Diplomaat",
  "Directeur",
  "Directieassistent",
  "Directiesecretaresse",
  "Dirigent",
  "Diskjockey",
  "Districtschef",
  "Districtsverpleegkundige",
  "Docent",
  "Documentalist",
  "Documentencontroleur",
  "Dokmeester",
  "Doktersassistent",
  "Dominee",
  "Doodgraver",
  "Douaneambtenaar",
  "Dozenmaker",
  "Draaier",
  "Dragartiest",
  "Dramadocent",
  "Dramatherapeut",
  "Drogist",
  "Drukker",
  "Drukkerijbinder",
  "Drukwerkvoorbereiders",
  "Drummer",
  "Duiker",
  "Econoom",
  "Ecotechnisch manager",
  "Edelmetaalbewerker",
  "Edelsmid",
  "Editor",
  "EDP-auditor",
  "Egyptoloog",
  "Eindredacteur",
  "Elektricien",
  "Elektromonteur",
  "Elektronicamonteur",
  "Elektronicus",
  "Elektrotechnicus",
  "Encyclopedist",
  "Enqu\u00eateur",
  "Entertainment-worstelaar",
  "Ergonoom",
  "Ergotherapeut",
  "Ertskundige",
  "Essayeur",
  "Essayist",
  "Etaleur",
  "Etnograaf",
  "Etnoloog",
  "Etymoloog",
  "Evangelist",
  "Examinator",
  "Expediteur",
  "Explantatiemedewerker",
  "Fabrikant",
  "Facilitair Manager",
  "Facturist",
  "Farmacoloog",
  "Fietsenmaker",
  "Fijnbankwerker",
  "Filiaalhouder",
  "Filmer",
  "Filmregisseur",
  "Filosoof",
  "Filterreiniger",
  "Financieel analist",
  "Fluitenbouwer",
  "Fotograaf",
  "Fotograveur (textieldruk)",
  "Fotolaborant",
  "Fotolaboratoriumbediende",
  "Fotolithograaf",
  "Fotoredacteur",
  "Framebouwer",
  "Frezer",
  "Fruitteler",
  "Fysicus",
  "Fysioloog",
  "Fysiotherapeut",
  "Galvaniseur",
  "Game Designer",
  "Garagehouder",
  "Garderobejuffrouw",
  "Garnalenpeller",
  "Gasleidinglegger",
  "Gastro-enteroloog",
  "Gastvrouw",
  "Gecommitteerde",
  "Gedeputeerde",
  "Gemeentesecretaris",
  "Geneeskundige",
  "Generaal",
  "Geodeet",
  "Geograaf",
  "Geoloog",
  "Gerant",
  "Gerechtsdeurwaarder",
  "Gereedschapsmaker",
  "Gereedschapssmid",
  "Geschiedkundige",
  "Gevangenbewaarder",
  "Gezaghebber",
  "Gezagvoerder",
  "Gezondheidsbegeleider",
  "Gezondheidsfysicus",
  "Gezondheidstechnicus",
  "Gidsenschrijver",
  "Gieterijtechnicus",
  "Gietmachinebediener",
  "Gigolo",
  "Gipsverbandmeester",
  "Gitarist",
  "Glasblazer",
  "Glasgraveur",
  "Glasslijper",
  "Glaszetter",
  "Glazenhaler",
  "Glazenmaker",
  "Glazenwasser",
  "Goochelaar",
  "Goudsmid",
  "Goudzoeker",
  "Grafdelver",
  "Graficus",
  "Grafisch ontwerper",
  "Grafoloog",
  "Graveur",
  "Griendwerker",
  "Griffier",
  "Grimeur",
  "Groenteteler",
  "Groepsleider",
  "Groepsvervoer",
  "Grondsteward",
  "Grondstewardess",
  "Grondwerker",
  "Groothandelaar",
  "Gymleraar",
  "Gynaecoloog",
  "Handelaar",
  "Handelscorrespondent",
  "Handwever",
  "Havenarbeider",
  "Havenmeester",
  "Heemraad",
  "Heftruckchauffeur",
  "Heibaas",
  "Heier",
  "Heilpedagoog",
  "Heilsoldaat",
  "Helpdeskmedewerker",
  "Herbergier",
  "Hijsmachinist",
  "Historicus",
  "Hoefsmid",
  "Hoekman",
  "Hofmeester",
  "Homeopaat",
  "Hondenfokker",
  "Hondentoiletteerder",
  "Hondentrimmer",
  "Hoofd",
  "Hoofdambtenaar",
  "Hoofdcontroleur",
  "Hoofdredacteur",
  "Hoofduitvoerder",
  "Hoofdverpleegkundige",
  "Hoofdwerktuigkundige",
  "Hoogleraar",
  "Hoornist",
  "Hoorspelregisseur",
  "Horlogemaker",
  "Hostess",
  "Hotelier",
  "Hotelmanager",
  "Hotelportier",
  "Houtbewerker",
  "Houtmodelmaker",
  "Houtsnijder",
  "Houtvester",
  "Houtwarensamensteller",
  "Hovenier",
  "Huidtherapeut",
  "Huisarts",
  "Huisbaas",
  "Huisbewaarder",
  "Huishoudhulp",
  "Huishoudster",
  "Huisschilder",
  "Hulparbeider",
  "Hulpautomonteur",
  "Hulpkok",
  "Hulpverkoper",
  "Huurmoordenaar",
  "Hydroloog",
  "IJscoman",
  "IJzervlechter",
  "Illusionist",
  "Illustrator",
  "Imam",
  "Imker",
  "Importeur",
  "Impresario",
  "Industrieel ontwerper",
  "Ingenieur",
  "Inkoper",
  "Inrijger",
  "Inseminator",
  "Inspecteur",
  "Installateur",
  "Instructeur",
  "Instrumentalist",
  "Instrumentmaker",
  "Interieurarchitect",
  "Interieurverzorger",
  "Interne accountant",
  "Internist",
  "Jachtopzichter",
  "Jager",
  "Jongleur",
  "Journalist",
  "Justitieel Aanklager",
  "Juwelier",
  "Judoleraar",
  "Kaartenzetter",
  "Kaasmaker",
  "Kabelsplitser",
  "Kabelwerker",
  "Kanaalmeester",
  "Kantonnier",
  "Kantoorhulp",
  "Kapitein",
  "Kapper",
  "Kappershulp",
  "Kardinaal",
  "Karteerder",
  "Kartonnagewerker",
  "Kassamedewerker",
  "Kassier",
  "Kelner",
  "Keizer",
  "Keramist",
  "Kermisexploitant",
  "Kernmaker",
  "Kerstman",
  "Ketelmetselaar",
  "Keukenassistent",
  "Keukenknecht",
  "Keurder",
  "Keuringsambtenaar",
  "Keurmeester",
  "Kinderverzorger",
  "Kinderboekenschrijver",
  "Kleerbleker",
  "Kleermaker",
  "Kleidelver",
  "Kleinhandelaar",
  "Klerk",
  "Kleuterleid(st)er",
  "Klokkenmaker",
  "Klompenmaker",
  "Kloosterling",
  "Kno-arts",
  "Koerier",
  "Koetsier",
  "Kok",
  "Komiek",
  "Kompel",
  "Kooiker",
  "Kooiman",
  "Koordirigent",
  "Koperslager",
  "Kostendeskundige",
  "Koster",
  "Kostprijscalculator",
  "Kozijnenmaker",
  "Kraamverzorgende",
  "Kraamhulp",
  "Kraanmachinist",
  "Kredietanalist",
  "Kredietbeoordelaar",
  "Kruidendokter",
  "Kruier",
  "Kuiper",
  "Kunstcriticus",
  "Kunstenaar",
  "Kunstschilder",
  "Kustlichtwachter",
  "Kwitantieloper",
  "Laadschopbestuurder",
  "Laborant",
  "Laboratoriumbediende",
  "Lader",
  "Ladingmeester",
  "Lakei",
  "Landarbeider",
  "Landbouwer",
  "Landbouwkundige",
  "Landbouwmachinebestuurder",
  "Landbouwmilieubeheer",
  "Landbouwwerktuigenhersteller",
  "Landmeetkundige",
  "Landmeettechnicus",
  "Landmeter",
  "Landschapsarchitect",
  "Landschapsbeheer",
  "Lasinspecteur",
  "Lasser",
  "Lastechnicus",
  "Lector",
  "Ledertechnoloog",
  "Lederwarenmaker",
  "Leerbewerker",
  "Leerkracht",
  "Leeuwentemmer",
  "Legionair (Romeins)",
  "Leidekker",
  "Leidinggevende",
  "Leraar",
  "Letterkundige",
  "Leurder",
  "Lichtdrukker",
  "Lichtmatroos",
  "Lijstenmaker",
  "Linktrainer",
  "Literator",
  "Literatuurcriticus",
  "Literatuuronderzoeker",
  "Logopedist",
  "Logotherapeut",
  "Lokettist",
  "Longarts",
  "Longfunctieassistent",
  "Loodgieter",
  "Loods",
  "Loodschef",
  "Loonadministrateur",
  "Loopbaancoach",
  "Losser",
  "Luchtverkeersleider",
  "Maatnemer",
  "Maatschappelijk medewerker",
  "Maatschappelijk werker",
  "Maatschoenmaker",
  "Machine vouwer",
  "Machinebankwerker",
  "Machinebediende",
  "Machinesteller",
  "Manegehouder",
  "Machinist",
  "Magazijnbediende",
  "Magazijnbeheerder",
  "Magazijnknecht",
  "Magnetiseur",
  "Makelaar",
  "Managementassistent",
  "Manager",
  "Mandenmaker",
  "Mannequin",
  "Manueel therapeut",
  "Marconist",
  "Marinier",
  "Maritiem Officier",
  "Marechaussee",
  "Marketingadviseur",
  "Marketingassistent",
  "Marktkoopman",
  "Marktzanger",
  "Masseur",
  "Mathematicus",
  "Matroos",
  "Mattenmaker",
  "Medewerker",
  "Mediatrainer",
  "Meester restauratiestukadoor",
  "Meettechnicus",
  "Melkboer",
  "Metaalbewerker",
  "Metaalbrander",
  "Metaalbuiger",
  "Metaalfrezer",
  "Metaalgieter",
  "Metaalkundige",
  "Meteoroloog",
  "Meteropnemer",
  "Metselaar",
  "Meubelbeeldhouwer",
  "Meubelmaker",
  "Meubelstoffeerder",
  "Meubelstoffennaaister",
  "Meubeltekenaar",
  "Mijnbouwkundige",
  "Middenstander",
  "Mijnwerker",
  "Milieudeskundige",
  "Milieuhygi\u00ebnist",
  "Militair",
  "Mimespeler",
  "Min",
  "Mineralenbewerker",
  "Minister",
  "Minister-president",
  "Model",
  "Modelmaker",
  "Modelnaaister",
  "Molenaar",
  "Modeontwerper",
  "Mondhygi\u00ebnist",
  "Monnik",
  "Monteur",
  "Mosselman",
  "Motordemonteur",
  "Motordrijver",
  "Motormonteur",
  "Mouldroomtechnicus",
  "Munter",
  "Muntmeester",
  "Museumconservator",
  "Museumgids",
  "Museumhouder",
  "Museummedewerker",
  "Musicus",
  "Muziekinstrumentenmaker",
  "Muziekprogrammeur",
  "Naaister",
  "Nachtwaker",
  "Nagelstyliste",
  "Nasynchronisatieregisseur",
  "Natuurkundeleraar",
  "Natuurkundige",
  "Natuurwetenschapper",
  "Navigator",
  "Nefroloog",
  "Neonatoloog",
  "Nettenboeter",
  "Netwerkbeheerder",
  "Neurochirurg",
  "Neuroloog",
  "Neurofysioloog",
  "Nieuwslezer",
  "Nijverheidsconsulent",
  "Nko-arts",
  "Nopster",
  "Notaris",
  "Nucleair geneeskundige",
  "Ober",
  "Oberkelner",
  "Objectleider",
  "Oceanoloog",
  "Octrooigemachtigde",
  "Officier",
  "Officier van justitie",
  "Olieslager",
  "Omroeper",
  "Omsteller",
  "Oncoloog",
  "Onderhoudsloodgieter",
  "Onderhoudsman",
  "Onderhoudsmedewerker",
  "Onderhoudsmonteur",
  "Ondernemer",
  "Onderofficier",
  "Ondersteunende",
  "Onderwaterwerker",
  "Onderwijsassistent",
  "Onderwijstechnicus",
  "Onderwijzer",
  "Onderzoeker",
  "Onderzoeker in opleiding",
  "Ondist",
  "Ontdekkingsreiziger",
  "Ontmijner",
  "Ontvlekker",
  "Ontwerper",
  "Oogarts",
  "Operateur",
  "Operatieassistent",
  "Operational auditor",
  "Operator",
  "Opkoper",
  "Opperman",
  "Opsporingsambtenaar",
  "Opsporingsingenieur",
  "Opticien",
  "Optometrist",
  "Opvoedingsconsulent",
  "Opvoedingsvoorlichter",
  "Opzichter",
  "Organist",
  "Organizer",
  "Ornitholoog",
  "Orthodontist",
  "Orthopedagoog",
  "Orthopeed",
  "Orthoptist",
  "ORL-arts",
  "Osteopaat",
  "Ouvreuse",
  "Ovenman",
  "Paardenfokker",
  "Pakhuischef",
  "Paleontoloog",
  "Palfrenier",
  "Pandjesbaas",
  "Papierschepper",
  "Papiervernisser",
  "Parkeerwachter",
  "Parketvloerenlegger",
  "Parketwacht",
  "Pastoor",
  "Paswerker",
  "Patholoog",
  "Patholoog-anatoom",
  "Patissier",
  "Patroonmaker",
  "Patroontekenaar",
  "Pedagoog",
  "Pedicure",
  "Perronopzichter",
  "Perser",
  "Personeelsfunctionaris",
  "Peuterwerker",
  "Pianist",
  "Pianostemmer",
  "Piccolo",
  "Pijpfitter",
  "Pikeur",
  "Piloot",
  "Plaatwerker",
  "Planner",
  "Plantenteeltdeskundige",
  "Plantsoenmedewerker",
  "Plasticvormer",
  "Plastische chirurg",
  "Pleitbezorger",
  "Poelier",
  "Poepruimer of poepboer",
  "Poetser",
  "Podiatrist",
  "Podoloog",
  "Poffertjesbakker",
  "Polisopmaker",
  "Politicus",
  "Politieagent",
  "Politiecommissaris",
  "Politie-inspecteur",
  "Politiek analist",
  "Pontschipper",
  "Pooier",
  "Porder",
  "Portier",
  "Portretfotograaf",
  "Postbediende",
  "Postbesteller",
  "Postbode",
  "Postcommandant",
  "Postexpediteur",
  "Postsorteerder",
  "Pottenbakker",
  "Predikant",
  "Premier",
  "Presentator",
  "President",
  "Priester",
  "Probleemanalist",
  "Procesmanager",
  "Procesoperator",
  "Procureur",
  "Procureur des Konings",
  "Producer",
  "Productenmaker",
  "Productensorteerder",
  "Productiebegeleider",
  "Productieleider",
  "Productiemedewerker",
  "Productieplanner",
  "Professor",
  "Programmamaker",
  "Programmeur",
  "Projectadviseur",
  "Projectleider",
  "Projectmanager",
  "Projectontwikkelaar",
  "Promovendus",
  "Prostitu\u00e9",
  "Prostituee",
  "Pruikenmaker",
  "Psychiater",
  "Psychologisch assistent",
  "Psycholoog",
  "Psychotherapeut",
  "Psychomotorisch kindertherapeut",
  "Purser",
  "Putjesschepper",
  "Quarantaine-beambte",
  "Quizmaster",
  "Quantity surveyor",
  "Raadsman: advocaat of adviseur",
  "Radarwaarnemer",
  "Radiotherapeutisch laborant",
  "Radiograaf",
  "Radiolaborant",
  "Radiotechnicus",
  "Radiotelegrafist",
  "Rangeerder",
  "Recensent",
  "Receptionist (Receptioniste)",
  "Recherchekundige",
  "Rechercheur",
  "Rechtbanktekenaar",
  "Rechter",
  "Reclame-ontwerper",
  "Reclameacquisiteur",
  "Reclamedeskundige",
  "Reclametekenaar",
  "Redacteur",
  "Redactiechef",
  "Regisseur",
  "Registeraccountant",
  "Reiniger",
  "Reinigingsdienstarbeider",
  "Reisleider",
  "Reisprogrammeur",
  "Reisverkoper",
  "Rekenaar",
  "Rekwisietenmaker",
  "Rentmeester",
  "Reparateur",
  "Reumatoloog",
  "Ridder",
  "Repetitor",
  "Reproductietekenaar",
  "Restauranthouder",
  "Rietmeubelmaker",
  "Rietwerker",
  "Rijtuigspuiter",
  "Rijwielhersteller",
  "Rolluikentimmerman",
  "Rondvaartgids",
  "R\u00f6ntgenoloog",
  "Ruimtevaarder",
  "Samensteller",
  "Saunahouder",
  "Scenarioschrijver",
  "Schaaldierenkweker",
  "Schaaldierenpeller",
  "Schaapherder",
  "Schadecorrespondent",
  "Schadetaxateur",
  "Schakelbordwachter",
  "Schaker",
  "Schapenscheerder",
  "Scharensliep",
  "Scheepskapitein",
  "Scheepskok",
  "Scheepspurser",
  "Scheepsschilder",
  "Scheepstimmerman",
  "Scheidsrechter",
  "Scheikundige",
  "Schillenboer",
  "Schipper",
  "Schoenfabrieksarbeider",
  "Schoenhersteller",
  "Schoenmaker",
  "Schoolbegeleider",
  "Schooldecaan",
  "Schooldirecteur",
  "Schoolinspecteur",
  "Schoonheidsmasseur",
  "Schoonheidsspecialiste",
  "Schoonmaker",
  "Schoorsteenveger",
  "Schotter",
  "Schrijftolk",
  "Schrijver",
  "Schuurder",
  "Secretaresse",
  "Secretariaatsmedewerker",
  "Secretaris",
  "Seismoloog",
  "Seizoenarbeider",
  "Seksuoloog",
  "Selecteur",
  "Sergeant",
  "Seroloog",
  "Serveerster",
  "Setdresser",
  "Sigarenmaker",
  "Sinoloog",
  "Sjorder",
  "Sjouwer",
  "Slachter",
  "Slager",
  "Slagwerker",
  "Slijter",
  "Sloper",
  "Sluiswachter",
  "Smeerder",
  "Smelter",
  "Smid",
  "Snackbarbediende",
  "Snackbarhouder",
  "Snijder",
  "Sociotherapeut",
  "Softwareontwikkelaar",
  "Soldaat",
  "Soldeerder",
  "Sommelier",
  "Sondeerder",
  "Songwriter",
  "Souschef",
  "Spoeler",
  "Souffleur (toneel)",
  "Specialist",
  "Spelersmakelaar",
  "Speltherapeut",
  "Spindoppenmonteur",
  "Spion",
  "Sportinstructeur",
  "Sportman (-vrouw)",
  "Staatsraad (Belgi\u00eb)",
  "Staatsraad (Nederland)",
  "Stadsomroeper",
  "Stadstimmerman",
  "Stanser",
  "Stationschef",
  "Statisticus",
  "Stedenbouwkundige",
  "Steenbewerker",
  "Steenfabrikant",
  "Steenhouwer",
  "Steenzetter",
  "Steigerbouwer",
  "Steigermaker",
  "Stenotypist",
  "Stereotypeur",
  "Sterilisatieassistent",
  "Steward(ess)",
  "Stoelenmatter",
  "Stoffeerder",
  "Stomatoloog",
  "Storingsmonteur",
  "Straatverkoper",
  "Straatzanger",
  "Strandjutter",
  "Stratenmaker",
  "Stripper",
  "Stucwerker",
  "Stukadoor",
  "Stuurman",
  "Stuwadoor",
  "Stylist",
  "Stypengalvaniseur",
  "Surinamist",
  "Systeemanalist",
  "Systeembeheerder",
  "Systeemontwerper",
  "Systeemprogrammeur",
  "Takelaar",
  "Tandarts",
  "Tandartsassistente",
  "Tandtechnicus",
  "Tapper",
  "Taxichauffeur",
  "Taxidermist",
  "Technicus",
  "Technisch Oogheelkundig Assistent",
  "Technisch tekenaar",
  "Tegelzetter",
  "Tekenaar",
  "Tekstschrijver",
  "Telecommunicatiemonteur",
  "Telefoniste",
  "Telegrafist",
  "Televisieregisseur",
  "Televisietechnicus",
  "Telexist",
  "Tennisser",
  "Terrazzovloerlegger",
  "Terreinchef",
  "Tester",
  "Textieldrukker",
  "Textiellaborant",
  "Textielopmaker",
  "Textielproductenmaker",
  "Theateragent",
  "Theatertechnicus",
  "Therapeut",
  "Timmerman",
  "Tingieter",
  "Toetsenist",
  "Tolk",
  "Toneelfigurant",
  "Toneelmeester",
  "Toneelregisseur",
  "Toneelschrijver",
  "Toneelspeler",
  "Torenkraanmonteur",
  "Totalisatormedewerker",
  "Touringcarchauffeur",
  "Touwslager",
  "Traceur",
  "Trainingsacteur",
  "Traiteur",
  "Trambestuurder",
  "Transportplanner",
  "Treinbestuurder",
  "Treinconducteur",
  "Treindienstleider",
  "Treinduwer",
  "Treinmachinist",
  "Trekkerchauffeur",
  "Tuiger",
  "Tuinarchitect",
  "Tuinder",
  "Tuinman",
  "Typiste",
  "Uitgever",
  "Uitsmijter",
  "Uitvaartbegeleider",
  "Uitvinder",
  "Uitvoerder",
  "Uroloog",
  "Uurwerkmaker",
  "Vakkenvuller",
  "Valet",
  "Veearts",
  "Veehouder",
  "Veeverloskundige",
  "Veiligheidsbeambte",
  "Veilinghouder",
  "Verfspuiter",
  "Vergaderstenograaf",
  "Verhuizer",
  "Verhuurder",
  "Verkeersdienstsimulator",
  "Verkeersinspecteur",
  "Verkeerskundige",
  "Verkeersleider",
  "Verkeersonderzoeker",
  "Verkeersplanoloog",
  "Verkoopchef",
  "Verkoopstyliste",
  "Verkoper",
  "Verloskundige",
  "Verpleeghulp",
  "Verpleegkundige",
  "Verslaggever",
  "Verspaner",
  "Vertaler",
  "Vertegenwoordiger",
  "Vervoer",
  "Vervoersinspecteur",
  "Verwarmingsinstallateur",
  "Verwarmingsmonteur",
  "Verzekeringsagent",
  "Verzekeringsdeskundige",
  "Verzekeringsinspecteur",
  "Verzorgende",
  "Vicaris",
  "Videoclipregisseur",
  "Videojockey (televisie)",
  "Vioolbouwer",
  "Violist",
  "Vinoloog",
  "Viroloog",
  "Visagiste",
  "Visfileerder",
  "Visser",
  "Vj (artiest)",
  "Vleeswarenmaker",
  "Vlieger",
  "Vliegtuigplaatwerker",
  "Vliegtuigtimmerman",
  "Vloerlegger",
  "Voedingsmiddelentechnoloog",
  "Voedingsvoorlichter",
  "Voeger",
  "Voertuigbekleder",
  "Voetballer",
  "Volder of Voller",
  "Voorganger",
  "Voorlichter",
  "Voorlichtingsfunctionaris",
  "Voorraadadministrateur",
  "Voorzitter",
  "Vormende",
  "Vormenmaker",
  "Vormer",
  "Vormgever",
  "Vrachtwagenchauffeur",
  "Vuilnisman",
  "Vulkanoloog",
  "Vuurspuwer",
  "Vuurtorenwachter",
  "Vroedvrouw (Vroedmeester)",
  "Waard",
  "Waardijn",
  "Waarzegger",
  "Wachtcommandant",
  "Wachter",
  "Wachtmeester",
  "Wagenmaker",
  "Wasser",
  "Wasserettehouder",
  "Waterbouwkundige",
  "Webdesigner",
  "Weefmachinesteller",
  "Weerkundige",
  "Weerpresentator",
  "Wegenbouwarbeider",
  "Wegenbouwmachinist",
  "Wegmarkeerder",
  "Werkleider-dokmeester",
  "Werktuigbouwkundige",
  "Werktuigkundige",
  "Werkvoorbereider",
  "Wethouder",
  "Wijkmeester",
  "Wijnboer",
  "Winkelbediende",
  "Winkelier",
  "Wiskundige",
  "Wisselkassier",
  "Wisselmaker",
  "Woonbegeleider",
  "Xylofonist",
  "Yogaleraar",
  "Zaakwaarnemer",
  "Zakenman",
  "Zanger(es)",
  "Zeefdrukker",
  "Zeeman",
  "Zeepzieder",
  "Zeilmaker",
  "Zelfstandig ondernemer",
  "Zetter",
  "Ziekenhuisapotheker",
  "Ziekenhuishygi\u00ebnist",
  "Ziekenverzorgende",
  "Zilversmid",
  "Zweminstructeur",
  "Zo\u00f6loog"
)

#' Job provider for Netherlands
#'
#' @inherit JobProvider description details return
#' @family nl
#' @family NL
#' @export
#' @examples
#' x <- JobProvider_nl_NL$new()
#' x$render()
JobProvider_nl_NL <- R6::R6Class(
  inherit = JobProvider,
  "JobProvider_nl_NL",
  private = list(
    locale_ = "nl_NL",
    formats = job_formats_nl_nl
  )
)
